C============================================================================
C                nCTEQ Parton Distribution Functions:
C     
C     SetNPDF calls the PDS file by name, and uses ReadPDS
C	from CTEQ 6 distribution
C
C     FIO: 3 June 2011
C===========================================================================
      Subroutine SetNPDF (filename,ierr)
      Implicit Double Precision (A-H,O-Z)
      Character filename*(*)
      Character Tablefile*132
      Logical fmtpds  !*** New/Old Format of PDS file
      Common /Setchange/ Isetch
      save
      Isetch=1  !*** Tell Ctq6Pdf there is a new set:
      ierr=0
C ------------------------------------------------------------------------
      CALL TRMSTR(filename,Ifilename)  !*** find length of directory name
      Tablefile=filename(1:Ifilename)
      IU= NextUn()
      Open(IU, File=Tablefile, Status='OLD', Err=100)
      fmtpds=.TRUE.   !*** USE NEW PDS FORMAT   
      Call Readpds (IU,fmtpds)
      Close (IU)
      Return

 100  Print *, ' Data file ', Tablefile, ' cannot be opened '
     >  //'in SetNPDF!!'
c      Stop
      ierr=1
      return
      End
      

C============================================================================
C                nCTEQ Parton Distribution Functions:
C     
C     CtqNpdf make the (A,Z) isospin correction and calls Ctq6Pdf
C     If (A,Z)=1, the "nuclear proton" is returned
C
C	CtqNpdf(iparton,x,Q,iA,iZ)
C
C	Arguments : iparton - ID of a parton as in CTEQ 6 PDFs
C			x,Q     - Bjorken x & energy scale
C			iA, iZ  - atomic number & number of protons used for 
C				    the isospin correction (Note: to use PDFs 
C				    of partons of bound nucleons in a nucleus 
C      			    with A,Z, one has to read in the file 
C				    fitname_A_Z.pds with 
C				    SetNPDF('fitname_A_Z.pds',ierr) and set 
C				    here the correct values of A,Z)
C
C     FIO: 3 June 2011
C===========================================================================
      function  CtqNpdf(iparton,x,Q,iA,iZ)
      IMPLICIT DOUBLE PRECISION (A-H, O-Z)
      A=Float(iA)
      Z=Float(iZ)

      if(iparton.eq.-2) then
       result=Ctq6Pdf(-2,x,Q)*Z/A + Ctq6Pdf(-1,x,Q)*(A-Z)/A
      elseif(iparton.eq.-1) then
       result=Ctq6Pdf(-1,x,Q)*Z/A + Ctq6Pdf(-2,x,Q)*(A-Z)/A
      elseif(iparton.eq.1)  then
       result=Ctq6Pdf( 1,x,Q)*Z/A + Ctq6Pdf( 2,x,Q)*(A-Z)/A
      elseif(iparton.eq.2)  then
       result=Ctq6Pdf( 2,x,Q)*Z/A + Ctq6Pdf( 1,x,Q)*(A-Z)/A
      else 
        result=Ctq6Pdf (iparton,x,Q)
      endif

      CtqNpdf=result
      return
      end
      
C============================================================================
C                nCTEQ Parton Distribution Functions:
C     
C     Set2NPDFab allows to call two PDS files by their names, 
C     and uses ReadPDS from CTEQ 6 distribution.
C
C     TJ: 13 Oct 2015
C===========================================================================
      Subroutine Set2NPDF(filename1,filename2,ierr)
      Implicit Double Precision (A-H,O-Z)
      Character filename1*(*)
      Character filename2*(*)
      Character Tablefile*132
      Logical fmtpds  !*** New/Old Format of PDS file
      Common /Setchangea/ Isetcha
      Common /Setchangeb/ Isetchb
      Isetcha=1  !*** Tell Ctq6Pdf there is a new set:
      Isetchb=1  !*** Tell Ctq6Pdf there is a new set:
      ierr=0
C ------------------------------------------------------------------------
      CALL TRMSTR(filename1,Ifilename)  !*** find length of directory name
      Tablefile=filename1(1:Ifilename)
      IU= NextUn()
      Open(IU, File=Tablefile, Status='OLD', Err=100)
      fmtpds=.TRUE.   !*** USE NEW PDS FORMAT   
      Call Readpdsa (IU,fmtpds)
      Close (IU)

C ------------------------------------------------------------------------
      CALL TRMSTR(filename2,Ifilename)  !*** find length of directory name
      Tablefile=filename2(1:Ifilename)
      IU= NextUn()
      Open(IU, File=Tablefile, Status='OLD', Err=100)
      fmtpds=.TRUE.   !*** USE NEW PDS FORMAT   
      Call Readpdsb (IU,fmtpds)
      Close (IU)

      Return

 100  Print *, ' Data file ', Tablefile, ' cannot be opened '
     >  //'in SetNPDF!!'
c      Stop
      ierr=1
      return
      End

C============================================================================
C                nCTEQ Parton Distribution Functions:
C     
C     Ctq2Npdf makes the same isospin correction as CtqNpdf but allows
C	to switch between 2 pds files initialized by Set2NPDF.
C
C	Ctq2Npdf(iset,iparton,x,Q,iA,iZ)
C
C	Arguments : iset    - value 1 or 2 - ID of the pds file from 
C				    Set2NPDF(1,2,ierr)
C	            iparton - ID of a parton as in CTEQ 6 PDFs
C			x,Q     - Bjorken x & energy scale
C			iA, iZ  - atomic number & number of protons used for 
C				    the isospin correction (Note: to use PDFs 
C				    of partons of bound nucleons in a nucleus 
C      			    with A,Z, one has to read in the file 
C				    fitname_A_Z.pds with 
C				    SetNPDF('fitname_A_Z.pds',ierr) and set 
C				    here the correct values of A,Z)
C
C     TJ: 13 Oct 2015
C===========================================================================

      function  Ctq2Npdf(iset,iparton,x,Q,iA,iZ)
      IMPLICIT DOUBLE PRECISION (A-H, O-Z)
      Integer i

      A=dble(iA)
      Z=dble(iZ)

      if (iset.eq.1) then

        if(iparton.eq.-2) then
         result=Ctq6Pdfa(-2,x,Q)*Z/A + Ctq6Pdfa(-1,x,Q)*(A-Z)/A
        elseif(iparton.eq.-1) then
         result=Ctq6Pdfa(-1,x,Q)*Z/A + Ctq6Pdfa(-2,x,Q)*(A-Z)/A
        elseif(iparton.eq.1)  then
         result=Ctq6Pdfa( 1,x,Q)*Z/A + Ctq6Pdfa( 2,x,Q)*(A-Z)/A
        elseif(iparton.eq.2)  then
         result=Ctq6Pdfa( 2,x,Q)*Z/A + Ctq6Pdfa( 1,x,Q)*(A-Z)/A       
        else 
          result=Ctq6Pdfa (iparton,x,Q)
        endif
      else
        if(iparton.eq.-2) then
         result=Ctq6Pdfb(-2,x,Q)*Z/A + Ctq6Pdfb(-1,x,Q)*(A-Z)/A
        elseif(iparton.eq.-1) then
         result=Ctq6Pdfb(-1,x,Q)*Z/A + Ctq6Pdfb(-2,x,Q)*(A-Z)/A
        elseif(iparton.eq.1)  then
         result=Ctq6Pdfb( 1,x,Q)*Z/A + Ctq6Pdfb( 2,x,Q)*(A-Z)/A
        elseif(iparton.eq.2)  then
         result=Ctq6Pdfb( 2,x,Q)*Z/A + Ctq6Pdfb( 1,x,Q)*(A-Z)/A       
        else 
          result=Ctq6Pdfb (iparton,x,Q)
        endif
      endif

      Ctq2Npdf=result

      return
      end
c =======================================================